From cdda6b98d785f103d9be6643a99a882c0d65b64c Mon Sep 17 00:00:00 2001
From: fantu <fantu@ispconfig3>
Date: Sun, 21 Dec 2008 04:51:07 -0500
Subject: [PATCH] fix parse error

---
 interface/web/sites/shell_user_edit.php |  130 ++++++++++++++++++++++++++++++++++++++++---
 1 files changed, 121 insertions(+), 9 deletions(-)

diff --git a/interface/web/sites/shell_user_edit.php b/interface/web/sites/shell_user_edit.php
index be7ded6..c65b628 100644
--- a/interface/web/sites/shell_user_edit.php
+++ b/interface/web/sites/shell_user_edit.php
@@ -40,12 +40,10 @@
 
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
+require_once('tools.inc.php');
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 // Loading classes
 $app->uses('tpl,tform,tform_actions');
@@ -61,7 +59,7 @@
 			
 			// Get the limits of the client
 			$client_group_id = $_SESSION["s"]["user"]["default_group"];
-			$client = $app->db->queryOneRecord("SELECT limit_ftp_user FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = $client_group_id");
+			$client = $app->db->queryOneRecord("SELECT limit_shell_user FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = $client_group_id");
 			
 			// Check if the user may add another shell user.
 			if($client["limit_shell_user"] >= 0) {
@@ -74,6 +72,69 @@
 		
 		parent::onShowNew();
 	}
+
+	function onShowEnd() {
+		global $app, $conf, $interfaceConf;
+		/*
+		 * If the names are restricted -> remove the restriction, so that the
+		 * data can be edited
+		 */
+		
+		$app->uses('getconf');
+		$global_config = $app->getconf->get_global_config('sites');
+		$shelluser_prefix = ($global_config['shelluser_prefix'] == '')?'':str_replace('[CLIENTNAME]', $this->getClientName(), $global_config['shelluser_prefix']);
+		
+		if ($this->dataRecord['username'] != ""){
+			/* REMOVE the restriction */
+			$app->tpl->setVar("username", str_replace($shelluser_prefix , '', $this->dataRecord['username']));
+		}
+		if($_SESSION["s"]["user"]["typ"] == 'admin' || $app->auth->has_clients($_SESSION['s']['user']['userid'])) {
+			$app->tpl->setVar("username_prefix", $global_config['shelluser_prefix']);
+		} else {
+			$app->tpl->setVar("username_prefix", $shelluser_prefix);
+		}
+
+		parent::onShowEnd();
+	}
+	
+	function onSubmit() {
+		global $app, $conf;
+		
+		// Get the record of the parent domain
+		$parent_domain = $app->db->queryOneRecord("select * FROM web_domain WHERE domain_id = ".intval(@$this->dataRecord["parent_domain_id"]));
+		
+		// Set a few fixed values
+		$this->dataRecord["server_id"] = $parent_domain["server_id"];
+		
+		parent::onSubmit();
+	}
+	
+	function onBeforeInsert() {
+		global $app, $conf, $interfaceConf;
+
+		// check if the username is not blacklisted
+		$blacklist = file(ISPC_LIB_PATH.'/shelluser_blacklist');
+		foreach($blacklist as $line) {
+			if(strtolower(trim($line)) == strtolower(trim($this->dataRecord['username']))){
+				$app->tform->errorMessage .= 'The username is not allowed.';
+			}
+		}
+		unset($blacklist);
+
+		/*
+		 * If the names should be restricted -> do it!
+		 */
+		if ($app->tform->errorMessage == ''){
+			
+			$app->uses('getconf');
+			$global_config = $app->getconf->get_global_config('sites');
+			$shelluser_prefix = ($global_config['shelluser_prefix'] == '')?'':str_replace('[CLIENTNAME]', $this->getClientName(), $global_config['shelluser_prefix']);
+
+			/* restrict the names */
+			$this->dataRecord['username'] = $shelluser_prefix . $this->dataRecord['username'];
+		}
+		parent::onBeforeInsert();
+	}
 	
 	function onAfterInsert() {
 		global $app, $conf;
@@ -81,12 +142,43 @@
 		$web = $app->db->queryOneRecord("SELECT * FROM web_domain WHERE domain_id = ".intval($this->dataRecord["parent_domain_id"]));
 		$server_id = $web["server_id"];
 		$dir = $web["document_root"];
-		$uid = $web["system_user"];
-		$gid = $web["system_group"];
+		$puser = $web["system_user"];
+		$pgroup = $web["system_group"];
 		
-		$sql = "UPDATE shell_user SET server_id = $server_id, dir = '$dir', uid = '$uid', gid = '$gid' WHERE shell_user_id = ".$this->id;
+		// The FTP user shall be owned by the same group then the website
+		$sys_groupid = $web['sys_groupid'];
+		
+		$sql = "UPDATE shell_user SET server_id = $server_id, dir = '$dir', puser = '$puser', pgroup = '$pgroup', sys_groupid = '$sys_groupid' WHERE shell_user_id = ".$this->id;
 		$app->db->query($sql);
 		
+	}
+	
+	function onBeforeUpdate() {
+		global $app, $conf, $interfaceConf;
+		
+		// check if the username is not blacklisted
+		$blacklist = file(ISPC_LIB_PATH.'/shelluser_blacklist');
+		foreach($blacklist as $line) {
+			if(strtolower(trim($line)) == strtolower(trim($this->dataRecord['username']))){
+				$app->tform->errorMessage .= 'The username is not allowed.';
+			}
+		}
+		unset($blacklist);
+
+		/*
+		 * If the names should be restricted -> do it!
+		 */
+		if ($app->tform->errorMessage == '') {
+			/*
+			* If the names should be restricted -> do it!
+			*/
+			$app->uses('getconf');
+			$global_config = $app->getconf->get_global_config('sites');
+			$shelluser_prefix = ($global_config['shelluser_prefix'] == '')?'':str_replace('[CLIENTNAME]', $this->getClientName(), $global_config['shelluser_prefix']);
+			
+			/* restrict the names */
+			$this->dataRecord['username'] = $shelluser_prefix . $this->dataRecord['username'];
+		}
 	}
 	
 	function onAfterUpdate() {
@@ -95,6 +187,26 @@
 		
 	}
 	
+	function getClientName() {
+		global $app, $conf;
+	
+		if($_SESSION["s"]["user"]["typ"] != 'admin') {
+			// Get the group-id of the user
+			$client_group_id = $_SESSION["s"]["user"]["default_group"];
+		} else {
+			// Get the group-id from the data itself
+			$client_group_id = $this->dataRecord['client_group_id'];
+		}
+		/* get the name of the client */
+		$tmp = $app->db->queryOneRecord("SELECT name FROM sys_group WHERE groupid = " . $client_group_id);
+		$clientName = $tmp['name'];
+		if ($clientName == "") $clientName = 'default';
+		$clientName = convertClientName($clientName);
+		
+		return $clientName;
+	
+	}
+	
 }
 
 $page = new page_action;

--
Gitblit v1.9.1